#!/bin/bash
#


source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
boostdir=${PRODUCTS}/boost/v1_46_1/${flvr}-gcc45

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# setup gcc v4_5_1
setup gcc v4_5_1
gccver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccver} = "4.5" ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

echo "Building boost in ${boostdir}"

mkdir -p ${boostdir}/build
if [ ! -d ${boostdir}/build ]
then
   echo "ERROR: failed to create ${boostdir}/build"
   exit 1
fi

set -x

cd ${boostdir}/build
tar -xzf ${PRODUCTS}/boost/v1_46_1/source/boost_1_46_1.tar.gz
cd ${boostdir}/build/boost_1_46_1

./bootstrap.sh --prefix=${boostdir} --without-icu --without-libraries=python,mpi
./bjam
./bjam install

set +x

if [ ! -d ${boostdir}/lib ]
then
   echo "ERROR: failed to create ${boostdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building boost for flavor ${flvr}"
echo "Declaring boost v1_46_1 for this flavor"
if [ ${OS} = "Darwin" ]
then
   ups declare boost v1_46_1 -r boost/v1_46_1 -2 -m boost.table -q gcc45
else 
   ups declare boost v1_46_1 -r boost/v1_46_1 -4 -m boost.table -q gcc45
fi
setup boost v1_46_1 -q gcc45
echo "BOOST_LIB is ${BOOST_LIB}"

exit 0
